package com.caimei365.manager.config.utils;

import com.caimei.dfs.image.ImageUpload;
import com.caimei.dfs.image.beens.ImageSize;
import com.caimei.dfs.image.beens.ImageUploadInfo;
import com.caimei.utils.Encodes;
import com.caimei.utils.StringUtils;
import com.caimei365.manager.config.thinkgem.Global;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletRequest;
import javax.swing.*;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.*;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class UploadUtils {

	private  final static Logger logger = LoggerFactory.getLogger(UploadUtils.class);

	 /**
     * @param args
     */
    public static void main(String[] args) {
        String srcImgPath = "E:/work/文档/hehe/bg3282.jpg";
        String iconPath = "E:/work/文档/hehe/1.png";
        String targerPath = "E:/work/文档/hehe/test.jpg" ;
         // 给图片添加水印
        markImageByIcon(iconPath, srcImgPath, targerPath);
    }

    /**
     * 给图片添加水印
     * @param iconPath 水印图片路径
     * @param srcImgPath 源图片路径
     * @param targerPath 目标图片路径
     */
    public static void markImageByIcon(String iconPath, String srcImgPath,
            String targerPath) {
        markImageByIcon(iconPath, srcImgPath, targerPath, null) ;
    }

    /**
     * 给图片添加水印、可设置水印图片旋转角度
     * @param iconPath 水印图片路径
     * @param srcImgPath 源图片路径
     * @param targerPath 目标图片路径
     * @param degree 水印图片旋转角度
     */
    public static void markImageByIcon(String iconPath, String srcImgPath,
            String targerPath, Integer degree) {
        OutputStream os = null;
        try {
            Image srcImg = ImageIO.read(new File(srcImgPath));
            BufferedImage buffImg = new BufferedImage(srcImg.getWidth(null),
                    srcImg.getHeight(null), BufferedImage.TYPE_INT_RGB);
            // 得到画笔对象
            // Graphics g= buffImg.getGraphics();
            Graphics2D g = buffImg.createGraphics();

            // 设置对线段的锯齿状边缘处理
            g.setRenderingHint(RenderingHints.KEY_INTERPOLATION,
                    RenderingHints.VALUE_INTERPOLATION_BILINEAR);

            g.drawImage(srcImg.getScaledInstance(srcImg.getWidth(null), srcImg
                    .getHeight(null), Image.SCALE_SMOOTH), 0, 0, null);

            if (null != degree) {
                // 设置水印旋转
                g.rotate(Math.toRadians(degree),
                        (double) buffImg.getWidth() / 2, (double) buffImg
                                .getHeight() / 2);
            }
            // 水印图象的路径 水印一般为gif或者png的，这样可设置透明度
            ImageIcon imgIcon = new ImageIcon(iconPath);
            // 得到Image对象。
            Image img = imgIcon.getImage();
            float alpha = 0.5f; // 透明度
            g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_ATOP,
                    alpha));
            // 表示水印图片的位置
            g.drawImage(img, 0, 0, null);
            g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER));
            g.dispose();
            os = new FileOutputStream(targerPath);
            // 生成图片
            ImageIO.write(buffImg, "JPG", os);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                if (null != os)
                    os.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    /**
	 * 得到图片地址
	 * @param request
	 * @param maskTemplates
	 * @param iamgeArray
	 * @param imagesList
	 * @param largeImageList
	 * @throws UnsupportedEncodingException
	 */
	public static void getImagesPath(HttpServletRequest request, String maskTemplates, String[] iamgeArray,
			List<String> imagesList, List<String> largeImageList){
		for (String iamge : iamgeArray) {
			iamge=Encodes.urlDecode(iamge);
			if(!iamge.contains("http:") && !iamge.contains("https:")){
//			String realPath = request.getSession().getServletContext().getRealPath(iamge);
                String realPath = UploadImageUtils.getAbsolutePath(iamge);
//			realPath=Encodes.urlDecode(realPath);
			int pointerIndex = realPath.lastIndexOf(".");
			String targetPath = realPath.substring(0, pointerIndex)+"_watermask"+realPath.substring(pointerIndex);
			// 打水印
			markImageByIcon(maskTemplates, realPath, targetPath);

			// 保存到图片服务器
			ImageUploadInfo imageUploadInfo = saveImageSerivce(realPath, pointerIndex, targetPath);
			Map<String, String> slaveMap = imageUploadInfo.getSlaveMap();
			if(slaveMap == null) {
				logger.error("[LG]source ===> " + imageUploadInfo.getSource());
				logger.error("[LG]slaveMap ===> " + imageUploadInfo.getSlaveMap());
				imageUploadInfo = saveImageSerivce(realPath, pointerIndex, targetPath);
				slaveMap = imageUploadInfo.getSlaveMap();
			}
			String photoServer = Global.getConfig("photoServer");
			largeImageList.add(photoServer+imageUploadInfo.getSource()) ;

			imagesList.add(photoServer+slaveMap.get("500x500"));

			}else{
				String[] s = iamge.split("_500x500");
				largeImageList.add(s[0]+s[1]);
				imagesList.add((iamge));
			}
		}
	}

	/**
	 * 保存到图片服务器
	 * @param realPath
	 * @param pointerIndex
	 * @param targetPath
	 */
	public static ImageUploadInfo saveImageSerivce(String realPath, int pointerIndex, String targetPath) {
		ImageUploadInfo imageUploadInfo =new ImageUploadInfo();
		try {
			InputStream inStream = new FileInputStream(targetPath);
			List<ImageSize> sizeList = new ArrayList<>();
			ImageSize imageSize = new ImageSize(500);
			sizeList.add(imageSize);
			 imageUploadInfo = ImageUpload.resizeMaxSizeUpload(inStream, realPath.substring(pointerIndex+1), sizeList, null);
//			System.out.println("source ===> " + imageUploadInfo.getSource());
//			for(Map.Entry<String, String> entry : imageUploadInfo.getSlaveMap().entrySet()) {
//				System.out.println("key ===> " + entry.getKey() + "," + "value ===> " + entry.getValue());
//			}
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}
		return imageUploadInfo;
	}

	/**
     * 富文本内容处理
     * @author LG
     * @date  2016年8月31日
     * @version 1.0
     * @param text
     * @return
     */
    public static String textHandle(String text, String photoServer,HttpServletRequest request){
    	 text=Encodes.unescapeHtml(text);
		text = StringUtils.replace(text, "<body", "<div");
		text = StringUtils.replace(text, "</body>", "</div>");
		//infoContent=Encodes.urlDecode(infoContent);
		Document doc = Jsoup.parse(text);
		Elements links = doc.getElementsByTag("img");
		for (Element link : links) {
			  String linkSrc = link.attr("src");
              String linkSrcOld = link.attr("src");
			  if(StringUtils.isNotBlank(linkSrc) && !linkSrc.startsWith("http:") && !linkSrc.startsWith("https:") && !linkSrc.contains("uploadFile/ueditor") ){//不包含http开头的
//				  String realPath = Encodes.urlDecode(request.getSession().getServletContext().getRealPath(linkSrc));
                  linkSrc= Encodes.urlDecode(linkSrc);
                  String realPath = UploadImageUtils.getAbsolutePath(linkSrc);
				  int pointerIndex = realPath.lastIndexOf(".");
					ImageUploadInfo saveImageSerivce=new ImageUploadInfo();
					try {
						saveImageSerivce = UploadUtils.saveImageSerivce(realPath, pointerIndex,realPath);
						String src=photoServer+saveImageSerivce.getSource();
						text = StringUtils.replace(text, linkSrcOld, src);
					} catch (Exception e) {
						logger.error("图片上传错误:"+e.toString(),e);
					}

			  }
		}
		return text;
    }

}
