package com.caimei365.manager.controller.wechat;

import com.caimei365.manager.config.security.ConstantKey;
import com.caimei365.manager.config.security.JwtService;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.wechat.WechatReply;
import com.caimei365.manager.service.wechat.WechatReplyService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

/**
 * 微信公众号-回复配置
 *
 * @author : Charles
 * @date : 2022/1/6
 */
@RestController
@RequestMapping("/wechat/reply")
public class WechatReplyApi {

    @Resource
    private WechatReplyService wechatReplyService;
    @Resource
    private JwtService jwtService;

    /**
     * 获取回复配置列表
     *
     * @param type 类型： 1采美，2呵呵商城
     * @param title 回复素材标题
     * @param responseType   事件类型
     * @param msgType   回复类型
     * @param pageNum  页码
     * @param pageSize 每页大小
     */
    @GetMapping("/list")
    public ResponseJson<PaginationVo<WechatReply>> replyList(Integer type, String title, String responseType, String msgType,
                                                             @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                             @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return wechatReplyService.getReplyList(type, title, responseType, msgType, pageNum, pageSize);
    }

    /**
     * 根据ID获取回复配置
     */
    @GetMapping("/{id}")
    public ResponseJson<WechatReply> getReply(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("回复配置Id不能为空！", null);
        }
        return wechatReplyService.getReply(id);
    }

    /**
     * 根据ID更新回复配置
     */
    @PostMapping("/update/{id}")
    public ResponseJson<Void> updateReply(HttpServletRequest request, @PathVariable("id") Integer id, @RequestBody WechatReply reply) {
        if (null == id || id <= 0) {
            return ResponseJson.error("回复配置Id不能为空！", null);
        }
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return wechatReplyService.updateReply(id, reply, username);
    }

    /**
     * 添加回复配置
     */
    @PostMapping("/create")
    public ResponseJson<Void> addReply(HttpServletRequest request, @RequestBody WechatReply reply) {
        String token = request.getHeader(ConstantKey.TOKEN_NAME);
        String username = jwtService.getUsername(token);
        return wechatReplyService.addReply(reply, username);
    }

    /**
     * 根据ID删除回复配置
     */
    @PostMapping("/delete/{id}")
    public ResponseJson<Void> deleteReply(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("回复配置Id不能为空！", null);
        }
        return wechatReplyService.deleteReply(id);
    }
}
