package com.caimei365.manager.dao.svip;

import com.caimei365.manager.entity.caimei.CmUser;
import com.caimei365.manager.entity.caimei.MessageCenter;
import com.caimei365.manager.entity.caimei.product.Product;
import com.caimei365.manager.entity.caimei.svip.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/4/7
 */
@Mapper
public interface CmSvipHistoryDao {

    /**
     * 超级会员列表
     * @param vip
     * @return
     */
    List<CmSvipHistory> superFind(CmSvipHistory vip);

    /**
     * 获取状态
     * @param userId
     * @return
     */
    CmSvipHistory findEndTime(Long userId);

    /**
     * 机构信息
     * @param clubId
     * @param name
     * @param shortName
     * @return
     */
    List<CmUser> findUserList(@Param("clubId") Integer clubId, @Param("name") String name, @Param("shortName") String shortName);

    /**
     * 获取用户超级会员数据
     * @param userId
     * @return
     */
    CmSvipHistory findVipUser(String userId);

    /**
     * 添加消息
     * @param messageCenter
     */
    void addMessageCenter(MessageCenter messageCenter);

    void insertHistory(CmSvipHistory cmSvipHistory);

    void updateVip(CmSvipHistory cmSvipHistory);

    void giveVip(CmSvipHistory cmSvipHistory);

    /**
     * 获取购买记录
     * @param cmSvipHistory
     * @return
     */
    List<CmSvipHistory> findHistory(CmSvipHistory cmSvipHistory);

    /**
     * 状态
     * @param packageId
     * @return
     */
    Integer findDuration(Integer packageId);

    /**
     * 获取时间
     * @param id
     * @return
     */
    String findMonth(String id);

    CmVipCoupon vipCouponGet(String id);

    CmCoupon CmCouponGet(String id);

    NewCmShop newCmShopGet(String id);

    Integer findRedemptionCodeNum(String couponId);

    void updateByDelFlag(String couponId);

    void updateAssociateByDelFlag(String couponId);

    void updateVipCouponMonth(CmVipCoupon cmVipCoupon);
    void insertVipCouponMonth(CmVipCoupon cmVipCoupon);

    void deleteByMonthId(String montId);

    List<Integer> findByCouponId(String couponId);

    void insertCouponAssociate(CmCouponAssociate associate);

    void updateCouponAssociate(CmCouponAssociate a);

    void logicDeleteCouponAssociate(Integer id);

    void insertCoupon(CmCoupon cmCoupon);

    void updateCoupon(CmCoupon cmCoupon);

    /**
     * 超级会员专属优惠券
     * @param cmVipCoupon
     * @return
     */
    List<CmVipCoupon> findCouponList(CmVipCoupon cmVipCoupon);

    List<CmCouponAssociate> findByProductType(String couponId);

    NewCmShop getShopInfoByShopId(Integer shopId);

    List<String> getBindCoupons(String montId);

    /**
     * 专属优惠券配置
     * @return
     */
    List<CmCoupon> selconfigure();

    /**
     * 获取专属优惠券时间
     * @return
     */
    CmVipCoupon selMonthTime();

    /**
     * 新增vip优惠券月份关系
     * @param relation
     */
    void insertVipCouponRelation(CmVipCouponRelation relation);

    /**
     * 删除优惠券
     * @param id
     */
    void delCoupon(@Param("id") Integer id);
    void delSvipCoupon(@Param("id") Integer id);
    void delSvipProduct(@Param("id") Integer id);

    /**
     * 修改vip优惠券月份关系
     * @param relation
     */
    /*void updateVipCouponRelation(CmVipCouponRelation relation);*/

    List<CmCoupon> getCouponListByIds(@Param("bindCoupons") List<String> bindCoupons,@Param("couponType") String couponType,@Param("status") String status);

    /**
     * 供应商列表
     * @param newCmShop
     * @return
     */
    List<NewCmShop> findShopList(NewCmShop newCmShop);

    /**
     * 获取商品列表
     * @param product
     * @return
     */
    List<Product> findProductImage(Product product);
    /**
     * 超级会员优惠商品
     * @param svipProduct
     * @return
     */
    List<CmSvipProduct> findProductList(CmSvipProduct svipProduct);

    /**
     * 更新排序
     * @param sort
     * @param id
     */
    void updateSort(@Param("sort") Integer sort, @Param("id") Integer id);

    /**
     * 删除超级会员商品
     */
    void deleteSvipProducr(@Param("id") Integer id);

    /**
     * 删除超级会员商品sku
     */
    void deleteById(@Param("id") Integer id);
    /**
     * 超级会员商品编辑数据
     * @param productId
     * @return
     */
    List<CmSku> findSkuList(Integer productId);

    List<CmLadderPrice> findLadderPriceBySku(Integer skuId);

    CmSku getSvipSku(Integer skuId);

    CmSvipProduct getCmSvipProduct(Integer id);

    void deleteByProductId(Integer productId);

    void insertSkuPrice(CmSku s);

    void insertCmSvipProduct(CmSvipProduct cmSvipProduct);

    void updateCmSvipProduct(CmSvipProduct cmSvipProduct);

    /**
     * 超级会员宣传图
     * @return
     */
    CmSvipProductAdsImage getAdsImage();

    /**
     * 保存宣传图
     * @param adsImage
     */
    void saveAdsImage(CmSvipProductAdsImage adsImage);

    List<String> getAllUseDateList();

    /**
     * 商品sku数据
     * @param productId
     * @return
     */
    CmSku findSku(Integer productId);

    /**
     * 商品sku
     * @param productId
     * @return
     */
    CmSku findSvipSku(Integer productId);

    /**
     * 套餐配置
     * @return
     */
    List<CmSvipPackage> findPackage();

    /**
     * 更新超级会员套餐信息
     * @param price
     * @param duration
     * @param proportion
     */
    void updatePrice(@Param("price") Double price, @Param("duration") Integer duration, @Param("proportion") Integer proportion);
}
