package com.caimei365.manager.service.caimei.impl;

import cn.hutool.core.lang.Assert;
import com.alibaba.excel.util.StringUtils;
import com.caimei365.manager.dao.KeyWordDao;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.KeyWord;
import com.caimei365.manager.entity.caimei.enums.KeyWordEnum;
import com.caimei365.manager.service.caimei.KeyWordService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;


import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @author zzj
 */
@Slf4j
@Service
public class KeyWordServiceImpl implements KeyWordService {


    @Resource
    private KeyWordDao keyWordDao;

    @Override
    public ResponseJson<PaginationVo<KeyWord>> getKeyWordList(String keyword, Integer searchTimeCode, Integer fromSearch, String beginTime, String endTime, Integer labelStatus, int pageNum, int pageSize) {
        if (null != searchTimeCode && searchTimeCode > 0 && StringUtils.isEmpty(beginTime) && StringUtils.isEmpty(endTime)) {
            Map<String, String> timeVal = KeyWordEnum.getTimeVal(searchTimeCode);
            beginTime = timeVal.get("beginTime");
            endTime = timeVal.get("endTime");
        }
        if (!StringUtils.isEmpty(beginTime)) {
            beginTime += " 00:00:00";
        }
        if (!StringUtils.isEmpty(endTime)) {
            endTime += " 23:59:59";
        }
        PageHelper.startPage(pageNum, pageSize);
        List<KeyWord> keyWords = keyWordDao.findList(keyword, fromSearch, beginTime, endTime, labelStatus);
        PaginationVo<KeyWord> pageData = new PaginationVo<>(keyWords);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson joinLabel(String id) {
        Assert.notBlank(id);
        if (id.contains(",")) {
            String[] split = id.split(",");
            for (String s : split) {
                keyWordDao.updateLabelStatus(s);
            }
        } else {
            keyWordDao.updateLabelStatus(id);
        }
        return ResponseJson.success();
    }

    @Override
    public ResponseJson<PaginationVo<KeyWord>> getRecommendList(String keyword, String beginTime, String endTime, Integer pageNum, Integer pageSize) {
        if (!StringUtils.isEmpty(beginTime)) {
            beginTime += " 00:00:00";
        }
        if (!StringUtils.isEmpty(endTime)) {
            endTime += " 23:59:59";
        }
        PageHelper.startPage(pageNum, pageSize);
        List<KeyWord> keyWords = keyWordDao.findRecommendList(keyword, beginTime, endTime);
        PaginationVo<KeyWord> pageData = new PaginationVo<>(keyWords);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson ignoreLabel(String id) {
        Assert.notBlank(id);
        if (id.contains(",")) {
            String[] split = id.split(",");
            for (String s : split) {
                keyWordDao.updateRecommendFlag(s);
            }
        } else {
            keyWordDao.updateRecommendFlag(id);
        }
        return ResponseJson.success();
    }

    @Override
    public ResponseJson insertLabel(String keyword) {
        Integer keywordExist = keyWordDao.findKeywordExist(keyword);
        if (null == keywordExist) {
            keyWordDao.insertLabel(keyword);
            return ResponseJson.success();
        } else {
            return ResponseJson.success("关键词已存在");
        }
    }

    @Override
    public ResponseJson deleteLabel(String id) {
        Assert.notBlank(id);
        if (id.contains(",")) {
            String[] split = id.split(",");
            for (String s : split) {
                keyWordDao.updateDelFlag(s);
            }
        } else {
            keyWordDao.updateDelFlag(id);
        }
        return ResponseJson.success();
    }
}
