package com.caimei365.manager.service.caimei.user;

import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.CmShop;
import com.caimei365.manager.entity.caimei.CmShopLabel;
import com.caimei365.manager.entity.caimei.CmShopRelevance;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/3/15
 */
public interface CmShopLabelService {

    /**
     * 关联标签供应商列表
     *  @param cmShopRelevance 搜索条件
     *  @param pageNum 页码
     *  @param pageSize 页面数据数
     *  @return 返回
     */
    ResponseJson<PaginationVo<CmShopRelevance>> pageList(CmShopRelevance cmShopRelevance, Integer pageNum, Integer pageSize);

    /**
     * 供应商列表
     * @param shopId 供应商id
     * @param name 供应商名称
     * @param pageNum 页码
     * @param pageSize 页面数据数
     * @return 返回
     */
    ResponseJson<PaginationVo<CmShop>> shopList(String shopId, String name, Integer pageNum, Integer pageSize);

    /**
     * 添加供应商
     * @param shopId 供应商id
     * @return 返回
     */
    ResponseJson insertShopRelevance(Integer shopId);

    /**
     * 删除关联标签的供应商
     * @param relevanceId 供应商id
     * @return 返回
     */
    ResponseJson delShopRelevanceById(Integer relevanceId);

    /**
     * 供应商关联标签列表
     * @param relevanceId 供应商id
     * @param keyword 标签名
     * @param pageNum 页码
     * @param pageSize 页面数据数
     * @return 返回
     */
    ResponseJson<PaginationVo<CmShopLabel>> shopLabelList(Integer relevanceId, String keyword, Integer pageNum, Integer pageSize);

    /**
     * 标签列表
     * @param keyword 标签名
     * @param pageNum 页码
     * @param pageSize 页面数据数
     * @return 返回
     */
    ResponseJson<PaginationVo<CmShopLabel>> labelList(String shopId, String keyword, Integer pageNum, Integer pageSize);

    /**
     * 关联标签
     * @param relevanceId 供应商id
     * @param keywordIds 标签id或id集合
     * @return 返回
     */
    ResponseJson insertLabel(Integer relevanceId, String keywordIds);

    /**
     * 添加标签到标签库
     * @param keyword 标签
     * @return 返回
     */
    ResponseJson insertSearch(String keyword);
    /**
     * 删除供应商关联标签
     * @param labelIds id或id集合
     * @return 返回
     */
    ResponseJson upShopLabelList(String labelIds);
}
